// java wrapper for vtkPLSDynaReader object
//

package vtk;
import vtk.*;

public class vtkPLSDynaReader extends vtkLSDynaReader
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int CanReadFile_2(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_2(id0); }

  private native void SetController_3(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_3(id0); }

  private native long GetController_4();
  public vtkMultiProcessController GetController() {
    long temp = GetController_4();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkPLSDynaReader() { super(); }

  public vtkPLSDynaReader(long id) { super(id); }
  public native long   VTKInit();

}
